@@ -1,11 +1,11 @@
 package Net::DNS::SEC;
 
 #
-# $Id: SEC.pm 1394 2015-09-13 16:36:32Z willem $
+# $Id: SEC.pm 1396 2015-09-14 21:16:36Z willem $
 #
 use vars qw($VERSION $SVNVERSION);
-$VERSION    = '1.01_01';
-$SVNVERSION = (qw$LastChangedRevision: 1394 $)[1];
+$VERSION    = '1.01_02';
+$SVNVERSION = (qw$LastChangedRevision: 1396 $)[1];
 
 
 =head1 NAME
@@ -34,7 +34,7 @@ for Net::DNS in the use declaration.
 use strict;
 use base qw(Exporter);
 
-use Net::DNS qw(:DEFAULT);
+use Net::DNS 1.01 qw(:DEFAULT);
 
 use vars qw(@EXPORT);
 @EXPORT = ( @Net::DNS::EXPORT, qw(algorithm digtype key_difference) );
